package com.bwie.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bwie.common.log.annotation.Log;
import com.bwie.common.log.enums.BusinessType;
import com.bwie.common.security.annotation.RequiresPermissions;
import com.bwie.product.domain.MallProductCategoryInfo;
import com.bwie.product.service.IMallProductCategoryInfoService;
import com.bwie.common.core.web.controller.BaseController;
import com.bwie.common.core.domain.Result;
import com.bwie.common.core.utils.poi.ExcelUtil;

/**
 * 商品类型Controller
 *
 * @author bwie
 * @date 2023-12-24
 */
@RestController
@RequestMapping("/cate")
public class MallProductCategoryInfoController extends BaseController
{
    @Autowired
    private IMallProductCategoryInfoService mallProductCategoryInfoService;

    /**
     * 查询商品类型列表
     */
    @RequiresPermissions("product:cate:list")
    @GetMapping("/list")
    public Result list(MallProductCategoryInfo mallProductCategoryInfo)
    {
        List<MallProductCategoryInfo> list = mallProductCategoryInfoService.selectMallProductCategoryInfoList(mallProductCategoryInfo);
        return success(list);
    }

    /**
     * 导出商品类型列表
     */
    @RequiresPermissions("product:cate:export")
    @Log(title = "商品类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallProductCategoryInfo mallProductCategoryInfo)
    {
        List<MallProductCategoryInfo> list = mallProductCategoryInfoService.selectMallProductCategoryInfoList(mallProductCategoryInfo);
        ExcelUtil<MallProductCategoryInfo> util = new ExcelUtil<MallProductCategoryInfo>(MallProductCategoryInfo.class);
        util.exportExcel(response, list, "商品类型数据");
    }

    /**
     * 获取商品类型详细信息
     */
    @RequiresPermissions("product:cate:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(mallProductCategoryInfoService.selectMallProductCategoryInfoById(id));
    }

    /**
     * 新增商品类型
     */
    @RequiresPermissions("product:cate:add")
    @Log(title = "商品类型", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody MallProductCategoryInfo mallProductCategoryInfo)
    {
        return toAjax(mallProductCategoryInfoService.insertMallProductCategoryInfo(mallProductCategoryInfo));
    }

    /**
     * 修改商品类型
     */
    @RequiresPermissions("product:cate:edit")
    @Log(title = "商品类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody MallProductCategoryInfo mallProductCategoryInfo)
    {
        return toAjax(mallProductCategoryInfoService.updateMallProductCategoryInfo(mallProductCategoryInfo));
    }

    /**
     * 删除商品类型
     */
    @RequiresPermissions("product:cate:remove")
    @Log(title = "商品类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(mallProductCategoryInfoService.deleteMallProductCategoryInfoByIds(ids));
    }
}
