package com.bwie.product.service.impl;

import java.util.List;
import com.bwie.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bwie.product.mapper.MallProductCategoryInfoMapper;
import com.bwie.product.domain.MallProductCategoryInfo;
import com.bwie.product.service.IMallProductCategoryInfoService;

/**
 * 商品类型Service业务层处理
 *
 * @author bwie
 * @date 2023-12-24
 */
@Service
public class MallProductCategoryInfoServiceImpl implements IMallProductCategoryInfoService
{
    @Autowired
    private MallProductCategoryInfoMapper mallProductCategoryInfoMapper;

    /**
     * 查询商品类型
     *
     * @param id 商品类型主键
     * @return 商品类型
     */
    @Override
    public MallProductCategoryInfo selectMallProductCategoryInfoById(Long id)
    {
        return mallProductCategoryInfoMapper.selectMallProductCategoryInfoById(id);
    }

    /**
     * 查询商品类型列表
     *
     * @param mallProductCategoryInfo 商品类型
     * @return 商品类型
     */
    @Override
    public List<MallProductCategoryInfo> selectMallProductCategoryInfoList(MallProductCategoryInfo mallProductCategoryInfo)
    {
        return mallProductCategoryInfoMapper.selectMallProductCategoryInfoList(mallProductCategoryInfo);
    }

    /**
     * 新增商品类型
     *
     * @param mallProductCategoryInfo 商品类型
     * @return 结果
     */
    @Override
    public int insertMallProductCategoryInfo(MallProductCategoryInfo mallProductCategoryInfo)
    {
        mallProductCategoryInfo.setCreateTime(DateUtils.getNowDate());
        return mallProductCategoryInfoMapper.insertMallProductCategoryInfo(mallProductCategoryInfo);
    }

    /**
     * 修改商品类型
     *
     * @param mallProductCategoryInfo 商品类型
     * @return 结果
     */
    @Override
    public int updateMallProductCategoryInfo(MallProductCategoryInfo mallProductCategoryInfo)
    {
        mallProductCategoryInfo.setUpdateTime(DateUtils.getNowDate());
        return mallProductCategoryInfoMapper.updateMallProductCategoryInfo(mallProductCategoryInfo);
    }

    /**
     * 批量删除商品类型
     *
     * @param ids 需要删除的商品类型主键
     * @return 结果
     */
    @Override
    public int deleteMallProductCategoryInfoByIds(Long[] ids)
    {
        return mallProductCategoryInfoMapper.deleteMallProductCategoryInfoByIds(ids);
    }

    /**
     * 删除商品类型信息
     *
     * @param id 商品类型主键
     * @return 结果
     */
    @Override
    public int deleteMallProductCategoryInfoById(Long id)
    {
        return mallProductCategoryInfoMapper.deleteMallProductCategoryInfoById(id);
    }
}
